#!/bin/bash
# Get Linux distribution name
get_os_distribution() {
    if   [ -e /etc/debian_version ] ||
         [ -e /etc/debian_release ]; then
        # Check Ubuntu or Debian
        if [ -e /etc/lsb-release ]; then
            # Ubuntu
            distri_name="ubuntu"
			cat /etc/lsb-release > os
        else
            # Debian
            distri_name="debian"
			cat /etc/debian_version > os
        fi
    elif [ -e /etc/fedora-release ]; then
        # Fedra
        distri_name="fedora"
		cat /etc/fedora-release > os
    elif [ -e /etc/redhat-release ]; then
        if [ -e /etc/oracle-release ]; then
            # Oracle Linux
            distri_name="oracle"
			cat /etc/oracle-release > os
        else
            # Red Hat Enterprise Linux
            distri_name="redhat"
			cat /etc/redhat-release > os
        fi
    elif [ -e /etc/arch-release ]; then
        # Arch Linux
        distri_name="arch"
		cat /etc/arch-release > os
    elif [ -e /etc/turbolinux-release ]; then
        # Turbolinux
        distri_name="turbol"
		cat /etc/turbolinux-release > os
    elif [ -e /etc/SuSE-release ]; then
        # SuSE Linux
        distri_name="suse"
		cat /etc/SuSE-release > os
    elif [ -e /etc/mandriva-release ]; then
        # Mandriva Linux
        distri_name="mandriva"
		cat /etc/mandriva-release > os
    elif [ -e /etc/vine-release ]; then
        # Vine Linux
        distri_name="vine"
		cat /etc/vine-release > os
    elif [ -e /etc/gentoo-release ]; then
        # Gentoo Linux
        distri_name="gentoo"
		cat /etc/gentoo-release > os
    else
        # Other
        echo "unkown distribution"
        distri_name="unkown"
		cat /etc/system-release > os
    fi

    echo ${distri_name}
}

get_installtime() {
	if type rpm 2>/dev/null 1>/dev/null; then
		rpm -q basesystem --qf='%{installtime}\n' > os_install_1
	elif type repoquery 2>/dev/null 1>/dev/null; then
		repoquery -q basesystem --installed --qf='%{installtime}' > os_install_1
	fi

	ls -alct --time-style=+%Y%m%d%H%M%S / |tail -1|awk '{print $6}' > os_install_2
	
	# echo installtime
}

get_app() {
	if type dpkg-query 2>/dev/null 1>/dev/null; then
		dpkg-query --show -f '${binary:Package} ${version} ${binary:Package}:${Architecture}\n' > app
		grep " install " /var/log/dpkg.log > app_install
	elif type repoquery 2>/dev/null 1>/dev/null; then
		repoquery --all --installed --qf="%{name}  %{version}-%{release} %{installtime}" > app
	else
		rpm -qa --qf="%{name}  %{version}-%{release} %{installtime}\n" > app
	fi
	
	# echo app
}

get_oracle() {
	egrep -h -R '^情報: \"Oracle Database .+\"のインストール・タイプは\".+Edition.*\"' $ORACLE_BASE/oraInventory/logs/installActions*.log 2>/dev/null | awk -F \" '{print $2 "," $4}' > oracle
	egrep -h -R '^情報: \"Oracle Client .+\"のインストール・タイプは' $ORACLE_BASE/oraInventory/logs/installActions*.log 2>/dev/null | awk -F \" '{print $2}' >> oracle
	egrep -h -R '^INFO: Install type for \"Oracle Database .+\" is \".+Edition.*\"' $ORACLE_BASE/oraInventory/logs/installActions*.log 2>/dev/null | awk -F \" '{print $2 "," $4}' >> oracle
	egrep -h -R '^INFO: Install type for \"Oracle Client .+\" is ' $ORACLE_BASE/oraInventory/logs/installActions*.log 2>/dev/null | awk -F \" '{print $2}' >> oracle

}

check_dmi(){
	if [ -e /sys/devices/virtual/dmi/id/sys_vendor ]; then
		if [ -e /sys/devices/virtual/dmi/id/product_name ]; then
			if [ -e /sys/devices/virtual/dmi/id/product_serial ]; then
				if [ -e /sys/devices/virtual/dmi/id/product_uuid ]; then
					echo "1"
				fi
			fi
		fi
    fi
	
	echo "0"
}

check_cmd(){
	cmd=$1
	if type $cmd 2>/dev/null 1>/dev/null; then
		return 1
	else
		return 0
	fi
}

cmd_msg(){
	cmd=$1
	if type $cmd 2>/dev/null 1>/dev/null; then
		return 1
	else
		echo "コマンド「${cmd}」がインストールされていません"
		echo "インストール後に再度実行してください"
		exit
	fi
}

cmd_msg2(){
	cmd=$1
	if type $cmd 2>/dev/null 1>/dev/null; then
		return 1
	else
		echo "コマンド「${cmd}」がインストールされていません"
		return 0
	fi
}

file_msg(){
	file=$1
	if [ -e $file ]; then
		return 1
	else
		echo "コマンド「${file}」がインストールされていません"
		echo "インストール後に再度実行してください"
		exit
	fi
}

file_msg2(){
	file=$1
	if [ -e $file ]; then
		return 1
	else
		echo "コマンド「${file}」がインストールされていません"
		return 0
	fi
}

DMI=0
if [ -e /sys/devices/virtual/dmi/id/sys_vendor ]; then
	if [ -e /sys/devices/virtual/dmi/id/product_name ]; then
		if [ -e /sys/devices/virtual/dmi/id/product_serial ]; then
			if [ -e /sys/devices/virtual/dmi/id/product_uuid ]; then
				DMI=1
			fi
		fi
	fi
fi
check_cmd dmidecode
DMIC=$?
CMDDMI=1
if [ $DMI = 0 -a $DMIC = 0 ]; then
	echo "コマンド「dmidecode」がインストールされていません"
	CMDDMI=0
fi

cmd_msg2 hostname
CMDHOSTNAME=$?
cmd_msg2 domainname
CMDDNAME=$?
cmd_msg2 ls
CMDLS=$?
cmd_msg2 getconf
CMDGETCONF=$?
file_msg2 /proc/cpuinfo
CMDCPU=$?
file_msg2 /proc/meminfo
CMDMEM=$?
cmd_msg2 lsblk
CMDLSBLK=$?
cmd_msg2 df
CMDDF=$?
cmd_msg2 lspci
CMDPCI=$?
cmd_msg2 udevadm
CMDUDEV=$?
cmd_msg2 ip
CMDIP=$?

APPCMD=1
check_cmd dpkg-query
DPKG=$?
check_cmd repoquery
REPO=$?
check_cmd rpm
RPM=$?
if [ $DPKG = 0 -a $REPO = 0 -a $RPM = 0 ]; then
	echo "コマンド「dpkg-query」「repoquery」「rpm」がインストールされていません"
	APPCMD=0
fi

if [ $CMDDMI = 0 -o $APPCMD = 0 -o $CMDHOSTNAME = 0 -o $CMDDNAME = 0 -o $CMDLS = 0 -o $CMDGETCONF = 0 -o $CMDCPU = 0 -o $CMDMEM = 0 -o $CMDLSBLK = 0 -o $CMDDF = 0 -o $CMDPCI = 0 -o $CMDUDEV = 0 -o $CMDIP = 0 ]; then
	echo "インストール後に再度実行してください"
	exit
fi

outdir=/var/tmp/lvinventory/result
# read -p "資産管理番号を入力してください: " outdir
# if [ ! -n "$outdir" ]; then
#    echo "資産管理番号を入力してください"
#    exit
# fi

if [ ! -e $outdir ]; then
	mkdir -p $outdir
fi
cd $outdir


dmidecode -t system | egrep "Manufacturer|Product Name|Serial Number|UUID|^$" > dmidecode
grep -R --no-message ''  /sys/devices/virtual/dmi/id/ > grep_sys_devices

hostname > hostname
domainname > domainname

get_os_distribution

get_installtime

getconf LONG_BIT > arch

egrep "physical id|model name|cpu cores|cpu MHz|^$" /proc/cpuinfo > cpu
grep "MemTotal" /proc/meminfo > mem
lsblk -o type,model,size,kname -P -b > physical_disk
df -T -x tmpfs -B1 -l --portability > logical_disk
lspci -nn | grep VGA > video

NICS=($(ls -1 /sys/class/net))
for nic in ${NICS[@]}; do
  udevadm info --query=property --path=/sys/class/net/$nic 2>/dev/null > nic_$nic
  ip addr show dev $nic 2>/dev/null > ip_$nic
done

get_app
get_oracle

exit
